SelectionItemState class
Presentation state supplied to a per-sheet SelectionSheetItemBuilder.
- Annotations
Constructors
- SelectionItemState({required bool isSelected, required bool isEnabled, required String query})
-
Creates presentation state for an item.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEnabled → bool
-
Whether the item can be selected.
final
- isSelected → bool
-
Whether the item is currently selected.
final
- query → String
-
The current debounced search query.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited