SelectionSheetPage<T> class
One page returned by a remote selection loader.
- Annotations
Constructors
-
SelectionSheetPage({required List<
T> items, bool hasMore = false, Object? nextCursor}) -
Creates a page of items.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
Whether another page can be requested.
final
-
items
→ List<
T> -
Items in this page.
final
- nextCursor → Object?
-
Cursor to send with the next request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited